@@ -2,7 +2,7 @@ package Mojolicious::Plugin::SPNEGO;
 use Mojo::Base 'Mojolicious::Plugin';
 use Net::LDAP::SPNEGO;
 
-our $VERSION = '0.3.2';
+our $VERSION = '0.3.3';
 
 my %cCache;
 
@@ -34,7 +34,9 @@ sub register {
                 for ($status){
                     my $ldap = $cCache->{ldapObj} //= Net::LDAP::SPNEGO->new(
                         $cfg->{ad_server},
-                        debug=>$cfg->{ldap_debug}
+                        debug=>($cfg->{ldap_debug}//$ENV{SPNEGO_LDAP_DEBUG}//0),
+                        onerror=>'die',
+                        timeout=>5
                     );
                     /^Type1/ && do {
                         my $mesg = $ldap->bind_type1($AuthBase64);
@@ -140,7 +142,7 @@ or
 
 The plugin provides the following helper method:
 
-=head2 $c->ntlm_auth(ad_server => $AD_SERVER, web_proxy_mode => 1, auth_success_cb => $cb)
+=head2 $c->ntlm_auth(ad_server => $AD_SERVER, ldap_debug => 0, web_proxy_mode => 1, auth_success_cb => $cb)
 
 The C<ntlm_auth> method runs an NTLM authentication dialog with the browser
 by forwarding the tokens coming from the browser to the AD server specified
@@ -160,6 +162,16 @@ Note that windows will only do automatic NTLM SSO with hosts in the local zone
 so you may have to add your webserver to this group of machines in the
 Internet Settings dialog.
 
+=head1 DEBUGGING
+
+You can set the L<Net::LDAP> debug level by setting the 
+C<SPNEGO_LDAP_DEBUG> environment variable.
+
+ 1   Show outgoing packets (using asn_hexdump).
+ 2   Show incoming packets (using asn_hexdump).
+ 4   Show outgoing packets (using asn_dump).
+ 8   Show incoming packets (using asn_dump).
+
 =head1 EXAMPLE
 
 The included example script F<eg/demo.pl> shows how to use the plugin
